==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/CertificatePolicies.h <==
// public class gnu.java.security.x509.ext.CertificatePolicies

// class file dependencies
// @dep_class 84454c43caffaca6 gnu_java_security_x509_ext_CertificatePolicies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_CertificatePolicies_H_
#define _JC_gnu_java_security_x509_ext_CertificatePolicies_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs	_jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs	_jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$refs	_jc_gnu_java_security_x509_ext_CertificatePolicies$refs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs	_jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object	_jc_gnu_java_security_x509_ext_CertificatePolicies$object;

typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct	_jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods	_jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtable	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtype	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24CertificatePolicies;
};
extern _jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct _jc_gnu_java_security_x509_ext_CertificatePolicies$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_CertificatePolicies$method$_init$9463b8ffa1cabcba(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_gnu_java_security_x509_ext_CertificatePolicies$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *);
extern struct _jc_object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$getPolicies$5adbdc00eef4bbee(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *);
extern struct _jc_object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$getPolicyQualifierInfos$a4cad1c455e3a379(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_gnu_java_security_OID$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$getPolicies$5adbdc00eef4bbee;
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$getPolicyQualifierInfos$a4cad1c455e3a379;
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_CertificatePolicies$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *);
	struct _jc_object	*(*getPolicies$5adbdc00eef4bbee)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *);
	struct _jc_object	*(*getPolicyQualifierInfos$a4cad1c455e3a379)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_gnu_java_security_OID$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods	gnu_java_security_x509_ext_CertificatePolicies;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs {
	struct _jc_object	*policies;
	struct _jc_object	*policyQualifierInfos;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$refs {
    _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs	gnu_java_security_x509_ext_CertificatePolicies;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs	gnu_java_security_x509_ext_CertificatePolicies;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object {
	_jc_gnu_java_security_x509_ext_CertificatePolicies$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_CertificatePolicies$vtype _jc_gnu_java_security_x509_ext_CertificatePolicies$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_CertificatePolicies, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_CertificatePolicies$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_CertificatePolicies_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/CertificatePolicies.h <==
// public class gnu.java.security.x509.ext.CertificatePolicies

// class file dependencies
// @dep_class 86b72e4dcf17ffa4 gnu_java_security_x509_ext_CertificatePolicies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_CertificatePolicies_H_
#define _JC_gnu_java_security_x509_ext_CertificatePolicies_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs	_jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs	_jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$refs	_jc_gnu_java_security_x509_ext_CertificatePolicies$refs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs	_jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object	_jc_gnu_java_security_x509_ext_CertificatePolicies$object;

typedef struct _jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct	_jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods	_jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtable	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtype	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24CertificatePolicies;
};
extern _jc_gnu_java_security_x509_ext_CertificatePolicies$fields_struct _jc_gnu_java_security_x509_ext_CertificatePolicies$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_CertificatePolicies$method$_init$9463b8ffa1cabcba(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_x509_ext_CertificatePolicies$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$getPolicies$5adbdc00eef4bbee(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$getPolicyQualifierInfos$a4cad1c455e3a379(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_gnu_java_security_OID$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$getPolicies$5adbdc00eef4bbee;
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$getPolicyQualifierInfos$a4cad1c455e3a379;
extern _jc_method _jc_gnu_java_security_x509_ext_CertificatePolicies$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_CertificatePolicies$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_CertificatePolicies$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPolicies$5adbdc00eef4bbee)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPolicyQualifierInfos$a4cad1c455e3a379)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *, struct _jc_gnu_java_security_OID$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$vmethods	gnu_java_security_x509_ext_CertificatePolicies;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs {
	struct _jc_object	*policies;
	struct _jc_object	*policyQualifierInfos;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$refs {
    _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_refs	gnu_java_security_x509_ext_CertificatePolicies;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_CertificatePolicies$sub_nonrefs	gnu_java_security_x509_ext_CertificatePolicies;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_CertificatePolicies$object {
	_jc_gnu_java_security_x509_ext_CertificatePolicies$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_CertificatePolicies$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_CertificatePolicies$vtype _jc_gnu_java_security_x509_ext_CertificatePolicies$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_CertificatePolicies, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_CertificatePolicies$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_CertificatePolicies_H_ */
